package com.game.business.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.game.business.domain.AppUsersCashAccount;

/**
 * 用户提现账号Mapper接口
 *
 * @author game
 * @date 2024-09-07
 */
public interface AppUsersCashAccountMapper extends BaseMapper<AppUsersCashAccount> {
    /**
     * 查询用户提现账号
     *
     * @param id 用户提现账号主键
     * @return 用户提现账号
     */
    public AppUsersCashAccount selectAppUsersCashAccountById(Long id);

    /**
     * 查询用户提现账号列表
     *
     * @param appUsersCashAccount 用户提现账号
     * @return 用户提现账号集合
     */
    public List<AppUsersCashAccount> selectAppUsersCashAccountList(AppUsersCashAccount appUsersCashAccount);

    /**
     * 新增用户提现账号
     *
     * @param appUsersCashAccount 用户提现账号
     * @return 结果
     */
    public int insertAppUsersCashAccount(AppUsersCashAccount appUsersCashAccount);

    /**
     * 修改用户提现账号
     *
     * @param appUsersCashAccount 用户提现账号
     * @return 结果
     */
    public int updateAppUsersCashAccount(AppUsersCashAccount appUsersCashAccount);

    /**
     * 删除用户提现账号
     *
     * @param id 用户提现账号主键
     * @return 结果
     */
    public int deleteAppUsersCashAccountById(Long id);

    /**
     * 批量删除用户提现账号
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppUsersCashAccountByIds(Long[] ids);
}